==> mesian-v0.1.1.tar.bz2: mesian-v0.1.1/www-data/lib/Menu.php <==
<?

include_once $global["root"] . "/lib/Mail.php";
include_once $global["root"] . "/lib/Directories.php";
include_once $global["root"] . "/lib/Modules.php";

include_once $global["root"] . "/lib/Cards.php";

class Menu {

	var $Template;

	function Menu () {
		$this->Template = new Template;
	}

	function system () {
		global $global;

		if (! $_SESSION["user_authenticated"]) {
			$retval = $this->system_anonymous();
		} else if ($_SESSION["config_domain_admin"]) {
			$retval = $this->system_domain();
		} else {
			$retval = $this->system_authenticated();
		}

		return $retval;
	}

	function system_domain () {

		$retval = $this->Template->generate("/template/menu_system_domain");

		return $retval;
	}

	function system_anonymous () {

		$retval = $this->Template->generate("/template/global_forum_login_form");

		return $retval;
	}

	function system_authenticated () {
		global $global, $string;

		if (check_newmail($global["directory"]["tmp"])) {
			$system_menu["tmpmail_alert"] =
				sprintf("<a href=\"%s/mail?no=%s\"><img class=\"mesian\"
					src=\"%s/module/message/image/tmpmail_alert.gif\" title=\"%s\"></a>",
					$_SESSION["user_www_url"], $global["directory"]["tmp"],
					$_SESSION["user_www_url"], "Temp Mail Arrived !!");

			$system_menu["directory3"] = $string["directory3"];
		}

		if (check_newmail($global["directory"]["inbox"])) {
			$system_menu["newmail_alert"] =
				sprintf("<a href=\"%s/mail?no=%s\"><img class=\"mesian\"
					src=\"%s/module/message/image/newmail_alert.gif\" title=\"%s\"></a>",
					$_SESSION["user_www_url"], $global["directory"]["inbox"],
					$_SESSION["user_www_url"], "New Mail Arrived !!");

			$system_menu["directory1"] = $string["directory1"];
		}

		/*
		if (count($_SESSION["config_forum"]) > 0) {
			$system_menu["forum"] = $this->Template->generate("/template/menu_system_forum");
		}
		*/

		$retval =
			$this->Template->generate("/template/menu_system", $system_menu);

		return $retval;
	}

	function directory() {

		$Directories = new Directories();

		$retval = $Directories->return_menu($_SESSION["user_directory"]);

		return $retval;
	}

	function module () {

		$Modules = new Modules();
		$retval = $Modules->return_menu();

		return $retval;
	}

	function main () {

		switch ($_SESSION["user_menu"]) {
			case ("card") :
				$retval = $this->menu_card();
			break;

			default :
				if ($_SESSION["user_authenticated"] and $_SESSION["config_domain_admin"]) {
					$retval = $this->menu_domain();
				} else if ($_SESSION["user_authenticated"]) {
					$retval = $this->menu_mail();
				}

		}

		return $retval;
	}

	function menu_domain () {
		$retval = $this->Template->generate("/template/menu_domain");

		return $retval;
	}

	function menu_mail () {
		$menu["directory"] = $this->directory();
		$menu["module"] = $this->module();

		$retval = $this->Template->generate("/template/menu", $menu);

		return $retval;
	}

	function menu_card () {
		$C = new Cards;

		$a = $C->get_groups();
		while (list($i, $j) = each($a)) {
			$o["no"] = $i;
			$o["name"] = $j;
			$one["content"] .=
				$this->Template->generate("/module/card/template/menu_list_one", $o);
		}

		return $this->Template->generate("/module/card/template/menu_list", $one);
	}
}


/*
Description
-----------

Author
------
 Spike^ekipS <spike@spikeekips.net>

Changelog
---------

Usage
-----

*/

?>

==> mesian-v0.1.2.tar.bz2: mesian-v0.1.2/www-data/lib/Menu.php <==
<?

include_once $global["root"] . "/lib/Mail.php";
include_once $global["root"] . "/lib/Directories.php";
include_once $global["root"] . "/lib/Modules.php";

class Menu {

	var $Template;

	function Menu () {
		$this->Template = new Template;
	}

	function system () {
		global $global;

		if (! $_SESSION["user_authenticated"]) {
			$retval = $this->system_anonymous();
		} else if ($_SESSION["config_domain_admin"]) {
			$retval = $this->system_domain();
		} else {
			$retval = $this->system_authenticated();
		}

		return $retval;
	}

	function system_domain () {

		$retval = $this->Template->generate("/template/menu_system_domain");

		return $retval;
	}

	function system_anonymous () {

		$retval = $this->Template->generate("/template/global_forum_login_form");

		return $retval;
	}

	function system_authenticated () {
		global $global, $string;

		if (check_newmail($global["directory"]["tmp"])) {
			$system_menu["tmpmail_alert"] =
				sprintf("<a class=\"mesian\" href=\"%s/mail?no=%s\"><img class=\"mesian\"
					src=\"%s/module/message/image/tmpmail_alert.gif\" title=\"%s\"></a>",
					$_SESSION["user_www_url"], $global["directory"]["tmp"],
					$_SESSION["user_www_url"], "Temp Mail Arrived !!");

			$system_menu["directory3"] = $string["directory3"];
		}

		if (check_newmail($global["directory"]["inbox"])) {
			$system_menu["newmail_alert"] =
				sprintf("<a class=\"mesian\" href=\"%s/mail?no=%s\"><img class=\"mesian\"
					src=\"%s/module/message/image/newmail_alert.gif\" title=\"%s\"></a>",
					$_SESSION["user_www_url"], $global["directory"]["inbox"],
					$_SESSION["user_www_url"], "New Mail Arrived !!");

			$system_menu["directory1"] = $string["directory1"];
		}

		/*
		if (count($_SESSION["config_forum"]) > 0) {
			$system_menu["forum"] = $this->Template->generate("/template/menu_system_forum");
		}
		*/

		$retval =
			$this->Template->generate("/template/menu_system", $system_menu);

		return $retval;
	}

	function directory() {

		$Directories = new Directories();

		$retval = $Directories->return_menu($_SESSION["user_directory"]);

		return $retval;
	}

	function module () {

		$Modules = new Modules();
		$retval = $Modules->return_menu();

		return $retval;
	}

	function main () {

		switch ($_SESSION["tmp"]["menu"]) {

			case ("card") :
				$retval = $this->menu_card();
			break;

			default :
				if ($_SESSION["user_authenticated"] and $_SESSION["config_domain_admin"]) {
					$retval = $this->menu_domain();
				} else if ($_SESSION["user_authenticated"]) {
					$retval = $this->menu_mail();
				}

		}

		return $retval;
	}

	function menu_domain () {
		$retval = $this->Template->generate("/template/menu_domain");

		return $retval;
	}

	function menu_mail () {
		$menu["directory"] = $this->directory();
		$menu["module"] = $this->module();

		$retval = $this->Template->generate("/template/menu", $menu);

		return $retval;
	}

	function menu_card () {
		global $global;

		include_once $global["root"] . "/lib/Extend_card.php";

		$C = new Extend_card;

		$menu["directory"] = $C->return_menu ();
		$menu["module"] = $this->module();

		$retval = $this->Template->generate("/template/menu", $menu);


		return $retval;
	}
}


/*
Description
-----------

Author
------
 Spike^ekipS <spike@spikeekips.net>

Changelog
---------

Usage
-----

*/

?>
